@@ -1,15 +1,14 @@
-from .decorators import (
-    discover_project,
-    discover_model,
-    discover_trained_model,
-)
-
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+"""[summary]
+"""
+from .decorators import discover_model, discover_project, discover_trained_model
 from .projects import (
     parse_input_path,
     parse_input_project_name,
-    parse_input_subscription_id,
     parse_input_resource_group,
-    parse_input_workspace_name,
     parse_input_service_connection,
+    parse_input_subscription_id,
     parse_input_webapp_kind,
+    parse_input_workspace_name,
 )
