@@ -1,3 +1,8 @@
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+"""
+"""
+
 import click
 
 from .build import build as build_webapp
@@ -7,8 +12,13 @@ from .serve import serve as serve_webapp
 
 @click.group()
 def webapp_group():
-    """
-    Manage Python Web Apps.
+    """Manage Python Web Apps.
+
+    Commands:
+        |  build
+        |  init
+        |  serve
+
     """
     pass
 
